@@ -20,7 +20,7 @@ with 'MooseX::SimpleConfig';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
-our $VERSION = '2.55';
+our $VERSION = '2.56';
 
 =head1 NAME
 
@@ -203,7 +203,8 @@ sub submit_slurm{
             my $len = sysread $fh, $line, 4096;
             if(not defined $len){
                 # There was an error reading
-                $self->log->fatal("Error from child: $!");
+                #$self->log->fatal("Error from child: $!");
+                $self->log_main_messages('fatal', "Error from child: $!");
             } elsif ($len == 0){
                 # Finished reading from this FH because we read
                 # 0 bytes.  Remove this handle from $sel.
@@ -212,12 +213,15 @@ sub submit_slurm{
             } else { # we read data alright
                 if($fh == $outfh) {
                     $stdout .= $line;
-                    $self->log->info($line);
+                    #$self->log->info($line);
+                    $self->log_main_messages('debug', $line)
                 } elsif($fh == $errfh) {
                     $stderr .= $line;
-                    $self->log->error($line);
+                    #$self->log->error($line);
+                    $self->log_main_messages('error', $line);
                 } else {
-                    $self->log->fatal("Shouldn't be here!\n");
+                    #$self->log->fatal("Shouldn't be here!\n");
+                    $self->log_main_messages('fatal', "Shouldn't be here!");
                 }
             }
         }
